@@ -1,6 +1,8 @@
 from ._helpers import *  # noqa: F401, F403
 from ._distance import *  # noqa: F401, F403
 from ._report import *  # noqa: F401, F403
+from ._stability import *  # noqa: F401, F403
 from ._vis import *  # noqa: F401, F403
+from ._metrics import *  # noqa: F401, F403
 
-__version__ = '0.0.5'
+__version__ = '0.0.8'
