@@ -4,23 +4,40 @@ __all__ = [
     'get_docs', 'get_top_docs',
     'calc_terms_marg_probs', 'calc_topics_marg_probs',
     'calc_terms_probs_ratio']
+from warnings import warn
+from importlib.util import find_spec
 from typing import Union, Optional, Sequence, List
 from functools import partial
 from math import log
 from numpy import ndarray, zeros, argsort, array, arange, vstack
 from pandas import concat, Series, DataFrame
-from tomotopy import (
-    LDAModel as tomotopyLDA,
-    LLDAModel as tomotopyLLDA,
-    CTModel as tomotopyCT,
-    DMRModel as tomotopyDMR,
-    HDPModel as tomotopyHDP,
-    PTModel as tomotopyPT,
-    SLDAModel as tomotopySLDA,
-    GDMRModel as tomotopyGDMR)
-from gensim.models.ldamodel import LdaModel as gensimLDA
-from gensim.models.ldamulticore import LdaMulticore as gensimLDAMC
-from bitermplus._btm import BTM
+
+tomotopy_installed = find_spec('tomotopy')
+if tomotopy_installed:
+    from tomotopy import (
+        LDAModel as tomotopyLDA,
+        LLDAModel as tomotopyLLDA,
+        CTModel as tomotopyCT,
+        DMRModel as tomotopyDMR,
+        HDPModel as tomotopyHDP,
+        PTModel as tomotopyPT,
+        SLDAModel as tomotopySLDA,
+        GDMRModel as tomotopyGDMR)
+
+gensim_installed = find_spec('gensim')
+if gensim_installed:
+    from gensim.models.ldamodel import LdaModel as gensimLDA
+    from gensim.models.ldamulticore import LdaMulticore as gensimLDAMC
+
+bitermplus_installed = find_spec('bitermplus')
+if bitermplus_installed:
+    from bitermplus._btm import BTM
+
+
+def __warn_package_installation(package_name: str):
+    warn(
+        f'Please install "{package_name}" package to analyze its models.\n'
+        f'Run `pip install {package_name}` in the console.')
 
 
 def get_phi(
@@ -41,9 +58,11 @@ def get_phi(
 
     Returns
     -------
-    DataFrame
+    pandas.DataFrame
         Words vs topics matrix (phi).
     """
+    phi = None
+
     if _is_tomotopy(model):
 
         # Topics vs words distributions
@@ -72,19 +91,31 @@ def get_phi(
 
 
 def _is_tomotopy(model: object) -> bool:
-    tomotopy_models = [
-        tomotopyLDA, tomotopyLLDA, tomotopyCT, tomotopyDMR, tomotopyHDP,
-        tomotopyPT, tomotopySLDA, tomotopyGDMR]
-    return any(map(partial(isinstance, model), tomotopy_models))
+    if tomotopy_installed:
+        tomotopy_models = [
+            tomotopyLDA, tomotopyLLDA, tomotopyCT, tomotopyDMR, tomotopyHDP,
+            tomotopyPT, tomotopySLDA, tomotopyGDMR]
+        return any(map(partial(isinstance, model), tomotopy_models))
+    else:
+        __warn_package_installation("tomotopy")
+        return False
 
 
 def _is_gensim(model: object) -> bool:
-    gensim_models = [gensimLDA, gensimLDAMC]
-    return any(map(partial(isinstance, model), gensim_models))
+    if gensim_installed:
+        gensim_models = [gensimLDA, gensimLDAMC]
+        return any(map(partial(isinstance, model), gensim_models))
+    else:
+        __warn_package_installation("gensim")
+        return False
 
 
 def _is_btmplus(model: object) -> bool:
-    return isinstance(model, BTM)
+    if bitermplus_installed:
+        return isinstance(model, BTM)
+    else:
+        __warn_package_installation("bitermplus")
+        return False
 
 
 def get_theta(
@@ -104,7 +135,7 @@ def get_theta(
 
     Returns
     -------
-    DataFrame
+    pandas.DataFrame
         Topics vs documents matrix (theta).
     """
     theta = None
@@ -172,7 +203,7 @@ def get_top_docs(
         List of documents.
     model : object, optional
         Topic model instance.
-    theta : ndarray, optional
+    theta : numpy.ndarray, optional
         Topics vs documents matrix.
     corpus : Optional[List], optional
         Corpus for ``gensim`` model.
@@ -183,7 +214,7 @@ def get_top_docs(
 
     Returns
     -------
-    DataFrame
+    pandas.DataFrame
         Top documents.
 
     Raises
@@ -217,14 +248,14 @@ def calc_topics_marg_probs(
 
     Parameters
     ----------
-    theta : Union[DataFrame, ndarray]
+    theta : Union[pandas.DataFrame, numpy.ndarray]
         Topics vs documents matrix.
     topic_id : int, optional
         Topic index.
 
     Returns
     -------
-    Union[DataFrame, ndarray]
+    Union[pandas.DataFrame, numpy.ndarray]
         Marginal topics probabilities.
     """
     if topic_id:
@@ -243,14 +274,14 @@ def calc_terms_marg_probs(
 
     Parameters
     ----------
-    phi : Union[ndarray, DataFrame]
+    phi : Union[numpy.ndarray, pandas.DataFrame]
         Words vs topics matrix.
     word_id: Optional[int]
         Word index.
 
     Returns
     -------
-    Union[ndarray, Series]
+    Union[numpy.ndarray, pandas.Series]
         Marginal terms probabilities.
     """
     if word_id:
@@ -313,7 +344,7 @@ def calc_terms_probs_ratio(
 
     Parameters
     ----------
-    phi : DataFrame
+    phi : pandas.DataFrame
         Words vs topics matrix.
     topic : int
         Topic index.
@@ -333,7 +364,7 @@ def calc_terms_probs_ratio(
 
     Returns
     -------
-    DataFrame
+    pandas.DataFrame
         Words conditional and marginal probabilities.
     """
     p_cond_name = 'Conditional term probability, p(w|t)'
@@ -369,7 +400,7 @@ def get_relevant_terms(
 
     Parameters
     ----------
-    phi : Union[np.ndarray, DataFrame]
+    phi : Union[numpy.ndarray, pandas.DataFrame]
         Words vs topics matrix (phi).
     topic : int
         Topic index.
@@ -387,7 +418,7 @@ def get_relevant_terms(
 
     Returns
     -------
-    Series
+    pandas.Series
         Terms sorted by relevance (descendingly).
     """
     phi_topic = phi.iloc[:, topic]\
