@@ -1,5 +1,3 @@
-# TODO: interactive topic model report: scatter plot of topics,
-#       top words/docs in topic (number is controlled interactively)
 # TODO: heatmap of docs in topics
 # TODO: topic dynamics in time
 # TODO: word cloud
@@ -9,7 +7,7 @@ from typing import Union, Sequence
 from pandas import DataFrame, option_context
 from numpy import ndarray
 from altair import (
-    Chart, X, Y, Size, Color, value, Text, Scale, Legend)
+    AxisConfig, Chart, X, Y, Size, Color, value, Text, Scale, Legend)
 
 
 def plot_scatter_topics(
@@ -78,17 +76,17 @@ def plot_scatter_topics(
 
     Returns
     -------
-    Chart
+    altair.Chart
         Topics scatter plot.
     """
     if not chart_kws:
         chart_kws = {}
 
     if not x_kws:
-        x_kws = {'shorthand': x_col, 'axis': None}
+        x_kws = {'shorthand': x_col}
 
     if not y_kws:
-        y_kws = {'shorthand': y_col, 'axis': None}
+        y_kws = {'shorthand': y_col}
 
     if not circle_kws:
         circle_kws = {"opacity": 0.33, "stroke": 'black', "strokeWidth": 1}
@@ -105,7 +103,7 @@ def plot_scatter_topics(
             "size": Size(size_col, **size_kws)
             if size_col and not topics_coords[size_col].isna().any()
             else value(500)
-            }
+        }
 
     if not text_kws:
         text_kws = {"align": "center", "baseline": "middle"}
@@ -170,12 +168,13 @@ def plot_scatter_topics(
         .encode(**text_enc_kws)
 
     return (rule + rule2 + points + text)\
-        .configure_view(stroke='transparent')\
+        .configure_axis(labelFontSize=font_size, titleFontSize=font_size, grid=False)\
+        .configure(axis=AxisConfig(disable=True))\
+        .configure_view(stroke='transparent', strokeWidth=0)\
         .configure_legend(
             orient='bottom',
             labelFontSize=font_size,
-            titleFontSize=font_size)\
-        .configure_axis(labelFontSize=font_size, titleFontSize=font_size)
+            titleFontSize=font_size)
 
 
 def plot_terms(
@@ -216,7 +215,7 @@ def plot_terms(
 
     Returns
     -------
-    Chart
+    altair.Chart
         Terms probabilities chart.
     """
     if not x_kws:
@@ -240,7 +239,7 @@ def plot_terms(
             x=X(x_col, **x_kws),
             y=Y(y_col, **y_kws),
             color=Color(**color_kws)
-        )\
+    )\
         .configure_axis(labelFontSize=font_size, titleFontSize=font_size)\
         .configure_legend(
             labelFontSize=font_size, titleFontSize=font_size,
